import { Meta, Canvas, Controls } from "@storybook/blocks";
import * as ComponentStories from "./stateful-trainings.stories";

<Meta of={ComponentStories} name="Docs" />

# StatefulTrainings

The `<ux-iws-stateful-trainings>` component renders a list of `<ux-accordion>` items, grouped by category.
The component retrieves the data from the related `ContentDataProvider`.

If the API returns an TrainingItem with an empty events array (which ideally should not happen), the this specific TrainingItem won't be rendered. This is different to the previous version and also the reason, why there is no more `details` object inside the TrainingItem data.

<Canvas of={ComponentStories.Default}></Canvas>

## With Filter

The `<ux-iws-stateful-trainings>` is connected to the related `<ux-iws-stateful-filter>` with the same `scope` – the `scope` musst be the same as the `namespace` for the translations.

<Canvas of={ComponentStories.WithFilter}></Canvas>

## Content API

### Interface

```typescript
export interface TrainingItem extends Record<string, any> {
    title?: string;
    id: number;
    category: number | string;
    typeId: number;
    levels: string[];
    languages: string[];
    description: string;
    events: TrainingEvent[];
}

export interface TrainingEvent {
    startDate: string;
    languages: string[];
    duration: string;
    location: string;
    availability: number;
    detailsLink: string;
}

export interface TrainingSchema extends ContentDataSchema {
    category: {
        order: Array<number | string>;
    };
}
```

### Example Content Data

```JSON
{
  "totalCount": 22,
  "filteredCount": 22,
  "schema": { "category": { "order": [1001, 1002, 1003, 1004, 1005] } },
  "items": [
    {
      "title": "Bedienerkurs TruArc Weld 1000",
      "id": 1153222,
      "category": 1001,
      "typeId": 1,
      "format": "eLearning",
      "levels": ["beginner"],
      "languages": ["de", "en"],
      "description": "Sie sind in der Lage die Anlage zu bedienen um Aufträge abzuarbeiten. Sie erwerben die Kenntnisse eigene Schweißversuche an der Anlage durchzuführen, um die Bedienung der TruArc Weld zu festigen.",
      "events": [
        {
          "startDate": "25.03.2023",
          "languages": ["de", "en"],
          "duration": "7 Wochen",
          "location": "",
          "availability": 1000,
          "detailsLink": "#"
        }
      ]
    },
    {
      "title": "Bedienerkurs TruArc Weld 1000",
      "id": 1153222,
      "category": 1002,
      "typeId": 2,
      "format": "presence",
      "levels": ["beginner", "advanced"],
      "languages": ["de", "fr", "it"],
      "description": "Sie sind in der Lage die Anlage zu bedienen um Aufträge abzuarbeiten. Sie erwerben die Kenntnisse eigene Schweißversuche an der Anlage durchzuführen, um die Bedienung der TruArc Weld zu festigen.",
      "events": [
        {
          "startDate": "25.03.2023",
          "languages": ["de", "it"],
          "duration": "3 Tage",
          "location": "Global Training Center Ditzingen",
          "availability": 5,
          "detailsLink": "#"
        },
        {
          "startDate": "26.03.2023",
          "languages": ["de", "fr"],
          "duration": "4 Tage",
          "location": "Global Training Center Ditzingen",
          "availability": 10,
          "detailsLink": "#"
        },
        {
          "startDate": "27.03.2023",
          "languages": ["de"],
          "duration": "5 Tage",
          "location": "Global Training Center Ditzingen",
          "availability": 2,
          "detailsLink": "#"
        },
        {
          "startDate": "28.03.2023",
          "languages": ["de", "fr", "it"],
          "duration": "1 Tag",
          "location": "Global Training Center Ditzingen",
          "availability": 0,
          "detailsLink": "#"
        }
      ]
    },
    {
      "title": "Bedienerkurs TruArc Weld 1000",
      "id": 1153222,
      "category": 1002,
      "typeId": 2,
      "format": "blendedLearning",
      "levels": ["beginner"],
      "languages": ["en"],
      "description": "Sie sind in der Lage die Anlage zu bedienen um Aufträge abzuarbeiten. Sie erwerben die Kenntnisse eigene Schweißversuche an der Anlage durchzuführen, um die Bedienung der TruArc Weld zu festigen.",
      "events": [
        {
          "startDate": "25.03.2023",
          "languages": ["en"],
          "duration": "3 Tage",
          "location": "Global Training Center Ditzingen",
          "availability": 0,
          "detailsLink": "#"
        },
        {
          "startDate": "28.03.2023",
          "languages": ["en"],
          "duration": "4 Tage",
          "location": "Global Training Center Ditzingen",
          "availability": 20,
          "detailsLink": "#"
        }
      ]
    },
    {
      "title": "Bedienerkurs TruArc Weld 1000",
      "id": 1153222,
      "category": 1002,
      "typeId": 2,
      "levels": ["advanced"],
      "languages": ["de", "en"],
      "description": "Sie sind in der Lage die Anlage zu bedienen um Aufträge abzuarbeiten. Sie erwerben die Kenntnisse eigene Schweißversuche an der Anlage durchzuführen, um die Bedienung der TruArc Weld zu festigen.",
      "events": []
    }
  ]
}
```

## Filter API

The component is connected to any `<ux-iws-stateful-filter>` component with the same `scope`.

### Example Filter Data

```JSON
{
  "filterBlocks": [
    {
      "type": "dropdown",
      "name": "type",
      "filterItems": [
        {
          "name": "allTrainings",
          "value": "allTrainings",
          "label": "All Trainings",
          "disabled": false,
          "active": false
        },
        {
          "name": "consultation",
          "value": "consultation",
          "label": "Consultation",
          "disabled": false,
          "active": false
        },
        {
          "name": "operator",
          "value": "operator",
          "label": "Operator",
          "disabled": false,
          "active": false
        },
        {
          "name": "programming",
          "value": "programming",
          "label": "Programming",
          "disabled": false,
          "active": false
        },
        {
          "name": "maintenance",
          "value": "maintenance",
          "label": "Maintenance",
          "disabled": false,
          "active": false
        },
        {
          "name": "technologyAdvanced",
          "value": "technologyAdvanced",
          "label": "Technology & advanced trainings",
          "disabled": false,
          "active": false
        },
        {
          "name": "other",
          "value": "other",
          "label": "Other trainings & courses",
          "disabled": false,
          "active": false
        }
      ]
    },
    {
      "type": "dropdown",
      "name": "format",
      "filterItems": [
        {
          "name": "allFormats",
          "value": "allFormats",
          "label": "All Formats",
          "disabled": false,
          "active": false
        },
        {
          "name": "presence",
          "value": "presence",
          "label": "Presence",
          "disabled": false,
          "active": false
        },
        {
          "name": "online",
          "value": "online",
          "label": "Online",
          "disabled": false,
          "active": false
        },
        {
          "name": "blendedLearning",
          "value": "blendedLearning",
          "label": "Blended Learning",
          "disabled": false,
          "active": false
        },
        {
          "name": "eLearning",
          "value": "eLearning",
          "label": "E-Learning",
          "disabled": false,
          "active": false
        },
        {
          "name": "microtraining",
          "value": "microtraining",
          "label": "Microtraining",
          "disabled": false,
          "active": false
        },
        {
          "name": "presenceAtClient",
          "value": "presenceAtClient",
          "label": "Presence at Client",
          "disabled": false,
          "active": false
        }
      ]
    },
    {
      "type": "select",
      "multiple": false,
      "name": "languages",
      "options": [
        {
          "label": "English",
          "value": "en",
          "selected": false,
          "disabled": false
        },
        {
          "label": "German",
          "value": "de",
          "selected": true,
          "disabled": false
        }
      ]
    },
    {
      "type": "dropdown",
      "name": "location",
      "filterItems": [
        {
          "name": "allLocations",
          "value": "allLocations",
          "label": "All locations",
          "disabled": false,
          "active": true
        },
        {
          "name": "ditzingen",
          "value": "ditzingen",
          "label": "Ditzingen",
          "disabled": false,
          "active": false
        },
        {
          "name": "loremIpsum",
          "value": "lorem",
          "label": "Lorem ipsum",
          "disabled": false,
          "active": false
        }
      ]
    }
  ]
}
```

## Translations

All required translations for content data labels and values must be loaded in a script tag in the header.
Namespace:

<pre>"{ComponentStories.Default.namespace}"</pre>

Translations:

<pre>{JSON.stringify(ComponentStories.Default.translations, null, 2)}</pre>

```json
{
    "category": {
        "values": {
            "1001": "Betriebsanleitungen",
            "1004": "Software-Handbücher & Programmieranleitungen"
        }
    },
    "date": {
        "label": "Ausgabedatum"
    },
    "languages": {
        "label": "Sprachen",
        "values": {
            "en": "English",
            "de": "Deutsch",
            "fr": "Français",
            "it": "Italiano"
        }
    },
    "size": {
        "label": "Dateigröße"
    },
    "cta": {
        "label": "Download"
    }
}
```

## Developer Documentation

<Controls />
